autoplot.intDensTri: 2D-display of the Domain Used to Compute the Integral
Description
2D-display of the domain used to compute the integral.
Usage
# S3 method for intDensTri
autoplot(object, coord.plot = c("x", "y1"),
plot = TRUE, ...)Arguments
object
output of the function intDensTri.
coord.plot
[character vector] the x and y coordinates. Can be "x", "y1" to "yd", "z" if zmin was specified when calling intDensTri.
plot
[logical] should the plot be displayed?
...
[internal] Only used by the generic method.